@@ -10,7 +10,6 @@
 """
 
 import re
-from typing import TYPE_CHECKING
 
 from six import iteritems
 
@@ -19,9 +18,11 @@ from sphinx.directives import ObjectDescription
 from sphinx.domains import Domain, ObjType
 from sphinx.locale import l_, _
 from sphinx.roles import XRefRole
+from sphinx.util import logging
 from sphinx.util.nodes import make_refnode
 
-if TYPE_CHECKING:
+if False:
+    # For type annotation
     from typing import Any, Dict, Iterator, List, Tuple  # NOQA
     from docutils import nodes  # NOQA
     from sphinx.application import Sphinx  # NOQA
@@ -29,6 +30,7 @@ if TYPE_CHECKING:
     from sphinx.environment import BuildEnvironment  # NOQA
 
 
+logger = logging.getLogger(__name__)
 dir_sig_re = re.compile(r'\.\. (.+?)::(.*)$')
 
 
@@ -139,9 +141,13 @@ class ReSTDomain(Domain):
 
     def merge_domaindata(self, docnames, otherdata):
         # type: (List[unicode], Dict) -> None
-        # XXX check duplicates
         for (typ, name), doc in otherdata['objects'].items():
             if doc in docnames:
+                if (typ, name) in self.data['objects']:
+                    otherdoc = self.data['objects'][typ, name]
+                    logger.warning('duplicate description of %s %s, '
+                                   'other instance in %s' %
+                                   (typ, name, self.env.doc2path(otherdoc)))
                 self.data['objects'][typ, name] = doc
 
     def resolve_xref(self, env, fromdocname, builder, typ, target, node,
